@@ -49,10 +49,11 @@ def sym(
     aws_region: str,
     log_dir: Optional[str],
 ) -> None:
-    """Access resources managed by Sym workflows.
+    """
+    Access resources managed by Sym Flows.
 
-    Use these tools to work with your resources once you've gotten approval in
-    Slack.
+    Use this CLI to interact with resources you've received access to with Sym.
+    https://docs.symops.com/docs/setup-sym-cli
     """
     options.saml_client_type = choose_saml_client(saml_client_name, none_ok=True)
     options.debug = debug
