@@ -117,9 +117,8 @@ def get_identity(saml_client) -> dict:
     return sts_client.get_caller_identity()
 
 
-@contextmanager
-def _ssm_session(saml_client, params: Dict):
-    ssm_client = boto_client(saml_client, "ssm")
+@intercept_boto_errors
+def _ssm_command(saml_client, ssm_client, params: Dict):
     saml_client.dprint("SSM Session: ", params=params)
     response = ssm_client.start_session(**params)
     command = [
@@ -131,6 +130,13 @@ def _ssm_session(saml_client, params: Dict):
         json.dumps(params),
         ssm_client.meta.endpoint_url,
     ]
+    return response, command
+
+
+@contextmanager
+def _ssm_session(saml_client, params: Dict):
+    ssm_client = boto_client(saml_client, "ssm")
+    response, command = _ssm_command(saml_client, ssm_client, params=params)
     try:
         yield command
     finally:
@@ -141,7 +147,6 @@ def _ssm_session(saml_client, params: Dict):
 
 
 @contextmanager
-@intercept_boto_errors
 def ssm_ssh_session(saml_client, instance: str, port: int):
     params = {
         "Target": instance,
@@ -153,7 +158,6 @@ def ssm_ssh_session(saml_client, instance: str, port: int):
 
 
 @contextmanager
-@intercept_boto_errors
 def ssm_interactive_command(saml_client, instance: str, user: str, cmd: Sequence[str]):
     full_cmd = f"sudo run-parts /etc/update-motd.d; sudo su -l {user}"
     if len(cmd) > 0:
