@@ -5,6 +5,7 @@ from typing import List, Mapping, MutableMapping, Optional, TypedDict
 import immutables
 
 from sym.cli.helpers.config.base import ConfigBase, fail_ok
+from sym.cli.helpers.config.sym_config_file import _Config
 
 
 class ServerConfigSchema(TypedDict):
@@ -17,6 +18,7 @@ class ConfigSchema(TypedDict, total=False):
     org: str
     email: str
     default_resource: str
+    last_update_check: Optional[datetime]
     servers: MutableMapping[str, ServerConfigSchema]
 
 
@@ -37,6 +39,15 @@ class Config(ConfigBase[ConfigSchema]):
     def get_instance(cls, instance: str) -> Optional[ServerConfigSchema]:
         return cls.get_servers().get(instance)
 
+    @classmethod
+    def get_cli_name(cls) -> str:
+        config_dir = _Config.dir_name
+        if config_dir == "symflow":
+            return "sym-flow-cli"
+        elif config_dir == "sym":
+            return "sym-cli"
+        return config_dir
+
     @classmethod
     def find_instance_by_alias(
         cls, alias: str, ttl: timedelta = timedelta(days=1)
@@ -116,3 +127,12 @@ class Config(ConfigBase[ConfigSchema]):
             return cls.get_org() == "sym"
         except KeyError as e:
             return False
+
+    @classmethod
+    def check_for_update(cls, every=timedelta(days=1)):
+        now = datetime.now()
+        last_checked = cls.instance().get("last_update_check", now - every)
+        if now - last_checked >= every:
+            cls.instance()["last_update_check"] = now
+            return True
+        return False
