@@ -61,7 +61,7 @@ def resource_option(f):
     """
     option_decorator = click.option(
         "--resource",
-        help="the Sym resource to use",
+        help="The Sym resource to use",
         envvar=get_resource_env_vars(),
         default=lambda: Config.get_default("resource"),
         cls=EnvvarOption,
@@ -87,20 +87,20 @@ def ansible_options(f):
     options = [
         group.option(
             "--ansible-aws-profile",
-            help="the local AWS Profile to use for Ansible commands",
+            help="The local AWS Profile to use for Ansible commands",
             envvar="AWS_PROFILE",
             cls=EnvvarGroupedOption,
         ),
         group.option(
             "--ansible-sym-resource",
-            help="the Sym resource to use for Ansible commands",
+            help="The Sym resource to use for Ansible commands",
             envvar="SYM_ANSIBLE_RESOURCE",
             callback=_resource_arg_callback,
             cls=EnvvarGroupedOption,
         ),
         click.option(
             "--control-master/--no-control-master",
-            help="allow SSH ControlPath caching",
+            help="Allow SSH ControlPath caching",
             envvar=SYM_USE_CONTROL_MASTER,
             is_flag=True,
             default=check_ssh_version,
@@ -113,11 +113,13 @@ def ansible_options(f):
             is_flag=True,
             default=True,
             cls=EnvvarOption,
+            show_default=True,
         ),
         click.option(
             "--forks",
-            help="number of parallel subprocesses for ansible",
+            help="Number of parallel subprocesses for ansible",
             default=10,
+            show_default=True,
         ),
     ]
     return flow(options, f)
