@@ -19,18 +19,18 @@ from .os import has_command, reset_fds
 
 REQ_TIMEOUT = 1
 INSTALL_TIMEOUT = 30
-SYM_CLI = "sym-cli"
 
 
 class SymUpdater:
-    def __init__(self, cli=SYM_CLI):
-        self.module = importlib.import_module(cli.replace("-", "."))
+    def __init__(self):
+        cli_name = Config.get_cli_name()
+        self.module = importlib.import_module(cli_name.replace("-", "."))
         self.dir = Path(inspect.getfile(self.module)).parent
-        for _ in range(len(cli.split("-"))):
+        for _ in range(len(cli_name.split("-"))):
             self.dir = self.dir.parent
         self.latest_version: Optional[VersionInfo] = None
         self.url: Optional[dict] = None
-        self.cli = cli
+        self.cli = cli_name
 
     def _log(self, s, **kwargs):
         click.secho(s, err=True, **kwargs)
