@@ -78,3 +78,17 @@ def test_sym_config_exclusive_create_already_created(sandbox: Sandbox):
 
         with SymConfigFile(file_name=file_name) as f:
             assert f.read() == body
+
+
+def test_config_get_cli_name(sandbox: Sandbox):
+    with sandbox.push_xdg_config_home():
+        init("symflow")
+        assert Config.get_cli_name() == "sym-flow-cli"
+
+        init("unknown")
+        assert Config.get_cli_name() == "unknown"
+
+        # sym init must be done last to make sure cli stays in its own
+        # original state. otherwise, this will bleed into other tests.
+        init("sym")
+        assert Config.get_cli_name() == "sym-cli"
